/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.fleet;

import nl.cloudfarming.client.fleet.model.Fleet;
import nl.cloudfarming.client.fleet.model.FleetManager;
import java.io.IOException;
import org.netbeans.api.project.Project;
import org.netbeans.spi.project.ProjectFactory;
import org.netbeans.spi.project.ProjectState;
import org.openide.filesystems.FileObject;
import org.openide.util.Lookup;

/**
 *
 * @author Wytse Visser
 */
@org.openide.util.lookup.ServiceProvider(service = ProjectFactory.class)
public class FleetProjectFactory implements ProjectFactory {

    public static final String ICON = "nl/cloudfarming/client/fleet/fleet.png";
    public static final String FLEET_FILE = "fleet.flt";

    @Override
    public boolean isProject(FileObject projectDirectory) {
        return projectDirectory.getFileObject(FLEET_FILE) != null;
    }

    @Override
    public Project loadProject(FileObject dir, ProjectState state) throws IOException {
        FleetProject project = null;
        if (isProject(dir)) {
            FleetManager fleetManager = Lookup.getDefault().lookup(FleetManager.class);
            Fleet fleet = fleetManager.load(dir.getFileObject(FLEET_FILE));
            project = new FleetProject(dir, state, fleet);
        }
        return project;
    }

    @Override
    public void saveProject(final Project project) throws IOException, ClassCastException {
        FileObject projectRoot = project.getProjectDirectory();
        FleetManager fleetManager = Lookup.getDefault().lookup(FleetManager.class);
        Fleet fleet = project.getLookup().lookup(Fleet.class);
        fleetManager.save(fleet, projectRoot.createData(FLEET_FILE));
    }
}
