/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.fleet;

import org.netbeans.spi.project.ui.LogicalViewProvider;
import org.openide.filesystems.FileObject;
import org.openide.loaders.DataFolder;
import org.openide.loaders.DataObject;
import org.openide.loaders.DataObjectNotFoundException;
import org.openide.nodes.AbstractNode;
import org.openide.nodes.Children;
import org.openide.nodes.Node;
import org.openide.util.Exceptions;

/**
 *
 * @author Wytse Visser
 */
public class FleetProjectLogicalView implements LogicalViewProvider {

    private FleetProject project;

    FleetProjectLogicalView(FleetProject project) {
        this.project = project;
    }

    @Override
    public Node createLogicalView() {
        try {
            //Get the fleet directory, creating if deleted
            FileObject projectDirectory = project.getProjectDirectory();
            DataFolder fleetFolder = DataFolder.findFolder(projectDirectory);
            DataObject fleetObject = DataObject.find(projectDirectory.getFileObject(FleetProjectFactory.FLEET_FILE));

            //Get its default node-we'll wrap our node around it to change the
            //display name, icon, etc
            Node realFleetNode = fleetObject.getNodeDelegate();

            //This FilterNode will be our project node
            return new FleetNode(realFleetNode, fleetFolder.getNodeDelegate(), project);
        } catch (DataObjectNotFoundException donfe) {
            Exceptions.printStackTrace(donfe);
            //Fallback-the directory couldn't be created -
            //read-only filesystem or something evil happened
            return new AbstractNode(Children.LEAF);
        }
    }

    @Override
    public Node findPath(Node node, Object o) {
        return null;
    }
}
